@@ -21,10 +21,9 @@ import transaction
 # import Zope3 interfaces
 from zope.app.publication.zopepublication import ZopePublication
 from zope.catalog.interfaces import ICatalog
-from zope.component.interfaces import IComponentRegistry
+from zope.component.interfaces import IComponentRegistry, ISite
 from zope.dublincore.interfaces import IZopeDublinCore
 from zope.intid.interfaces import IIntIds
-from zope.location.interfaces import ISite
 from zope.processlifetime import IDatabaseOpenedWithRoot
 
 # import local interfaces
